"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PeerType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PeerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PeerType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PEER_TYPE_PUBLISHER_UNSPECIFIED: _PeerType.ValueType  # 0
    PEER_TYPE_SUBSCRIBER: _PeerType.ValueType  # 1

class PeerType(_PeerType, metaclass=_PeerTypeEnumTypeWrapper): ...

PEER_TYPE_PUBLISHER_UNSPECIFIED: PeerType.ValueType  # 0
PEER_TYPE_SUBSCRIBER: PeerType.ValueType  # 1
global___PeerType = PeerType

class _ConnectionQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConnectionQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConnectionQuality.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONNECTION_QUALITY_BAD_UNSPECIFIED: _ConnectionQuality.ValueType  # 0
    CONNECTION_QUALITY_POOR: _ConnectionQuality.ValueType  # 1
    CONNECTION_QUALITY_GOOD: _ConnectionQuality.ValueType  # 2

class ConnectionQuality(_ConnectionQuality, metaclass=_ConnectionQualityEnumTypeWrapper): ...

CONNECTION_QUALITY_BAD_UNSPECIFIED: ConnectionQuality.ValueType  # 0
CONNECTION_QUALITY_POOR: ConnectionQuality.ValueType  # 1
CONNECTION_QUALITY_GOOD: ConnectionQuality.ValueType  # 2
global___ConnectionQuality = ConnectionQuality

class _VideoQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoQuality.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIDEO_QUALITY_LOW_UNSPECIFIED: _VideoQuality.ValueType  # 0
    VIDEO_QUALITY_MID: _VideoQuality.ValueType  # 1
    VIDEO_QUALITY_HIGH: _VideoQuality.ValueType  # 2

class VideoQuality(_VideoQuality, metaclass=_VideoQualityEnumTypeWrapper): ...

VIDEO_QUALITY_LOW_UNSPECIFIED: VideoQuality.ValueType  # 0
VIDEO_QUALITY_MID: VideoQuality.ValueType  # 1
VIDEO_QUALITY_HIGH: VideoQuality.ValueType  # 2
global___VideoQuality = VideoQuality

class CallState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTICIPANTS_FIELD_NUMBER: builtins.int
    @property
    def participants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Participant]: ...
    def __init__(
        self,
        *,
        participants: collections.abc.Iterable[global___Participant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["participants", b"participants"]) -> None: ...

global___CallState = CallState

class Call(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CREATED_BY_USER_ID_FIELD_NUMBER: builtins.int
    HOST_USER_ID_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """the call type"""
    id: builtins.str
    """the call id"""
    created_by_user_id: builtins.str
    """the id of the user that created this call"""
    host_user_id: builtins.str
    """the id of the current host for this call"""
    @property
    def custom(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        created_by_user_id: builtins.str = ...,
        host_user_id: builtins.str = ...,
        custom: google.protobuf.struct_pb2.Struct | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom", b"custom", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by_user_id", b"created_by_user_id", "custom", b"custom", "host_user_id", b"host_user_id", "id", b"id", "type", b"type", "updated_at", b"updated_at"]) -> None: ...

global___Call = Call

class Participant(google.protobuf.message.Message):
    """those who are online in the call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    TRACK_LOOKUP_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___User: ...
    role: builtins.str
    online: builtins.bool
    @property
    def custom(self) -> google.protobuf.struct_pb2.Struct: ...
    video: builtins.bool
    audio: builtins.bool
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    session_id: builtins.str
    track_lookup_prefix: builtins.str
    def __init__(
        self,
        *,
        user: global___User | None = ...,
        role: builtins.str = ...,
        online: builtins.bool = ...,
        custom: google.protobuf.struct_pb2.Struct | None = ...,
        video: builtins.bool = ...,
        audio: builtins.bool = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        session_id: builtins.str = ...,
        track_lookup_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom", b"custom", "updated_at", b"updated_at", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "created_at", b"created_at", "custom", b"custom", "online", b"online", "role", b"role", "session_id", b"session_id", "track_lookup_prefix", b"track_lookup_prefix", "updated_at", b"updated_at", "user", b"user", "video", b"video"]) -> None: ...

global___Participant = Participant

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def custom(self) -> google.protobuf.struct_pb2.Struct: ...
    name: builtins.str
    image_url: builtins.str
    created_at: builtins.str
    updated_at: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        custom: google.protobuf.struct_pb2.Struct | None = ...,
        name: builtins.str = ...,
        image_url: builtins.str = ...,
        created_at: builtins.str = ...,
        updated_at: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom", b"custom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom", b"custom", "id", b"id", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams", "updated_at", b"updated_at"]) -> None: ...

global___User = User

class StreamQuality(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_QUALITY_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    video_quality: global___VideoQuality.ValueType
    user_id: builtins.str
    def __init__(
        self,
        *,
        video_quality: global___VideoQuality.ValueType = ...,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id", "video_quality", b"video_quality"]) -> None: ...

global___StreamQuality = StreamQuality

class VideoDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    width: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "width", b"width"]) -> None: ...

global___VideoDimension = VideoDimension

class VideoLayer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RID_FIELD_NUMBER: builtins.int
    VIDEO_DIMENSION_FIELD_NUMBER: builtins.int
    BITRATE_FIELD_NUMBER: builtins.int
    rid: builtins.str
    """for tracks with a single layer, this should be HIGH"""
    @property
    def video_dimension(self) -> global___VideoDimension: ...
    bitrate: builtins.int
    """target bitrate, server will measure actual"""
    def __init__(
        self,
        *,
        rid: builtins.str = ...,
        video_dimension: global___VideoDimension | None = ...,
        bitrate: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["video_dimension", b"video_dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bitrate", b"bitrate", "rid", b"rid", "video_dimension", b"video_dimension"]) -> None: ...

global___VideoLayer = VideoLayer

class SimulcastCodecInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIME_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    mime_type: builtins.str
    mid: builtins.str
    cid: builtins.str
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoLayer]: ...
    def __init__(
        self,
        *,
        mime_type: builtins.str = ...,
        mid: builtins.str = ...,
        cid: builtins.str = ...,
        layers: collections.abc.Iterable[global___VideoLayer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "layers", b"layers", "mid", b"mid", "mime_type", b"mime_type"]) -> None: ...

global___SimulcastCodecInfo = SimulcastCodecInfo

class Codec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIME_FIELD_NUMBER: builtins.int
    FMTP_LINE_FIELD_NUMBER: builtins.int
    CLOCK_RATE_FIELD_NUMBER: builtins.int
    HW_ACCELERATED_FIELD_NUMBER: builtins.int
    mime: builtins.str
    fmtp_line: builtins.str
    clock_rate: builtins.int
    hw_accelerated: builtins.bool
    def __init__(
        self,
        *,
        mime: builtins.str = ...,
        fmtp_line: builtins.str = ...,
        clock_rate: builtins.int = ...,
        hw_accelerated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["clock_rate", b"clock_rate", "fmtp_line", b"fmtp_line", "hw_accelerated", b"hw_accelerated", "mime", b"mime"]) -> None: ...

global___Codec = Codec

class AudioCodecs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODES_FIELD_NUMBER: builtins.int
    DECODES_FIELD_NUMBER: builtins.int
    @property
    def encodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Codec]: ...
    @property
    def decodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Codec]: ...
    def __init__(
        self,
        *,
        encodes: collections.abc.Iterable[global___Codec] | None = ...,
        decodes: collections.abc.Iterable[global___Codec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decodes", b"decodes", "encodes", b"encodes"]) -> None: ...

global___AudioCodecs = AudioCodecs

class VideoCodecs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODES_FIELD_NUMBER: builtins.int
    DECODES_FIELD_NUMBER: builtins.int
    @property
    def encodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Codec]: ...
    @property
    def decodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Codec]: ...
    def __init__(
        self,
        *,
        encodes: collections.abc.Iterable[global___Codec] | None = ...,
        decodes: collections.abc.Iterable[global___Codec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["decodes", b"decodes", "encodes", b"encodes"]) -> None: ...

global___VideoCodecs = VideoCodecs

class CodecSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> global___AudioCodecs: ...
    @property
    def video(self) -> global___VideoCodecs: ...
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoLayer]: ...
    def __init__(
        self,
        *,
        audio: global___AudioCodecs | None = ...,
        video: global___VideoCodecs | None = ...,
        layers: collections.abc.Iterable[global___VideoLayer] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio", "video", b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "layers", b"layers", "video", b"video"]) -> None: ...

global___CodecSettings = CodecSettings

class ICETrickle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEER_TYPE_FIELD_NUMBER: builtins.int
    ICE_CANDIDATE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    peer_type: global___PeerType.ValueType
    ice_candidate: builtins.str
    session_id: builtins.str
    def __init__(
        self,
        *,
        peer_type: global___PeerType.ValueType = ...,
        ice_candidate: builtins.str = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ice_candidate", b"ice_candidate", "peer_type", b"peer_type", "session_id", b"session_id"]) -> None: ...

global___ICETrickle = ICETrickle



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/client_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.client_v1_rpc import envelopes_pb2 as video_dot_coordinator_dot_client__v1__rpc_dot_envelopes__pb2
from video.coordinator.edge_v1 import edge_pb2 as video_dot_coordinator_dot_edge__v1_dot_edge__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.stat_v1 import stat_pb2 as video_dot_coordinator_dot_stat__v1_dot_stat__pb2
from video.coordinator.utils_v1 import utils_pb2 as video_dot_coordinator_dot_utils__v1_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0video/coordinator/client_v1_rpc/client_rpc.proto\x12&stream.video.coordinator.client_v1_rpc\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$video/coordinator/call_v1/call.proto\x1a/video/coordinator/client_v1_rpc/envelopes.proto\x1a$video/coordinator/edge_v1/edge.proto\x1a$video/coordinator/push_v1/push.proto\x1a$video/coordinator/stat_v1/stat.proto\x1a&video/coordinator/utils_v1/utils.proto\"\"\n\x0eGetCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\"U\n\x0fGetCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"A\n\x0bMemberInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\"\x80\x01\n\x18UpsertCallMembersRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x44\n\x07members\x18\x02 \x03(\x0b\x32\x33.stream.video.coordinator.client_v1_rpc.MemberInput\x12\x0c\n\x04ring\x18\x03 \x01(\x08\"\x1b\n\x19UpsertCallMembersResponse\">\n\x18\x44\x65leteCallMembersRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x10\n\x08user_ids\x18\x02 \x03(\t\"\x1b\n\x19\x44\x65leteCallMembersResponse\"\xb4\x01\n\x0f\x43reateCallInput\x12?\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x31.stream.video.coordinator.client_v1_rpc.CallInput\x12\x44\n\x07members\x18\x02 \x03(\x0b\x32\x33.stream.video.coordinator.client_v1_rpc.MemberInput\x12\x11\n\x04ring\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x07\n\x05_ring\"\x81\x01\n\x11\x43reateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x02id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInputB\x05\n\x03_id\"z\n\x16GetOrCreateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInput\"\x8a\x01\n\x0fJoinCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInput\x12\x15\n\rdatacenter_id\x18\x04 \x01(\t\"\x9e\x01\n\x10JoinCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x08\x12\x35\n\x05\x65\x64ges\x18\x03 \x03(\x0b\x32&.stream.video.coordinator.edge_v1.Edge\"`\n\tCallInput\x12\x13\n\x0b\x63ustom_json\x18\x01 \x01(\x0c\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"n\n\x17GetOrCreateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x08\"g\n\x11UpdateCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12@\n\x05input\x18\x02 \x01(\x0b\x32\x31.stream.video.coordinator.client_v1_rpc.CallInput\"X\n\x12UpdateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"X\n\x12\x43reateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"z\n\x11QueryCallsRequest\x12\x0f\n\x07mq_json\x18\x01 \x01(\x0c\x12\x12\n\x05limit\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x05sorts\x18\x03 \x03(\x0b\x32\'.stream.video.coordinator.utils_v1.SortB\x08\n\x06_limit\"Z\n\x12QueryCallsResponse\x12\x44\n\x05\x63\x61lls\x18\x01 \x01(\x0b\x32\x35.stream.video.coordinator.client_v1_rpc.CallsEnvelope\"|\n\x13QueryMembersRequest\x12\x0f\n\x07mq_json\x18\x01 \x01(\x0c\x12\x12\n\x05limit\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x05sorts\x18\x03 \x03(\x0b\x32\'.stream.video.coordinator.utils_v1.SortB\x08\n\x06_limit\"`\n\x14QueryMembersResponse\x12H\n\x07members\x18\x01 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.MembersEnvelope\"y\n\x18GetCallEdgeServerRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12K\n\x0cmeasurements\x18\x02 \x01(\x0b\x32\x35.stream.video.coordinator.edge_v1.LatencyMeasurements\"\xa3\x01\n\x19GetCallEdgeServerResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x42\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.edge_v1.Credentials\"S\n\x13\x43reateDeviceRequest\x12<\n\x05input\x18\x01 \x01(\x0b\x32-.stream.video.coordinator.push_v1.DeviceInput\"P\n\x14\x43reateDeviceResponse\x12\x38\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32(.stream.video.coordinator.push_v1.Device\"!\n\x13\x44\x65leteDeviceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteDeviceResponse\"\x15\n\x13QueryDevicesRequest\"Q\n\x14QueryDevicesResponse\x12\x39\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32(.stream.video.coordinator.push_v1.Device\"o\n\x10SendEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12I\n\nevent_type\x18\x02 \x01(\x0e\x32\x35.stream.video.coordinator.client_v1_rpc.UserEventType\"\x13\n\x11SendEventResponse\"K\n\x16SendCustomEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x11\n\tdata_json\x18\x03 \x01(\x0c\"\x19\n\x17SendCustomEventResponse\">\n\x16ReportCallStatsRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x12\n\nstats_json\x18\x02 \x01(\x0c\"\x19\n\x17ReportCallStatsResponse\"\xba\x01\n\x1aReportCallStatEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x13media_state_changed\x18\x03 \x01(\x0b\x32\x33.stream.video.coordinator.stat_v1.MediaStateChangedH\x00\x42\x07\n\x05\x65vent\"\x1d\n\x1bReportCallStatEventResponse\"\'\n\x13GetCallStatsRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\"P\n\x12ReportIssueRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\"\x15\n\x13ReportIssueResponse\"^\n\x11ReviewCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\r\n\x05stars\x18\x02 \x01(\x02\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\"\x14\n\x12ReviewCallResponse*\x9a\x01\n\rUserEventType\x12\x1f\n\x1bUSER_EVENT_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1dUSER_EVENT_TYPE_ACCEPTED_CALL\x10\x01\x12!\n\x1dUSER_EVENT_TYPE_REJECTED_CALL\x10\x02\x12\"\n\x1eUSER_EVENT_TYPE_CANCELLED_CALL\x10\x03\x32\x8f\x14\n\tClientRPC\x12\x83\x01\n\nCreateCall\x12\x39.stream.video.coordinator.client_v1_rpc.CreateCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.CreateCallResponse\x12\x92\x01\n\x0fGetOrCreateCall\x12>.stream.video.coordinator.client_v1_rpc.GetOrCreateCallRequest\x1a?.stream.video.coordinator.client_v1_rpc.GetOrCreateCallResponse\x12}\n\x08JoinCall\x12\x37.stream.video.coordinator.client_v1_rpc.JoinCallRequest\x1a\x38.stream.video.coordinator.client_v1_rpc.JoinCallResponse\x12\x98\x01\n\x11GetCallEdgeServer\x12@.stream.video.coordinator.client_v1_rpc.GetCallEdgeServerRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.GetCallEdgeServerResponse\x12\x83\x01\n\nUpdateCall\x12\x39.stream.video.coordinator.client_v1_rpc.UpdateCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.UpdateCallResponse\x12\x83\x01\n\nQueryCalls\x12\x39.stream.video.coordinator.client_v1_rpc.QueryCallsRequest\x1a:.stream.video.coordinator.client_v1_rpc.QueryCallsResponse\x12\x89\x01\n\x0cQueryMembers\x12;.stream.video.coordinator.client_v1_rpc.QueryMembersRequest\x1a<.stream.video.coordinator.client_v1_rpc.QueryMembersResponse\x12\x89\x01\n\x0c\x43reateDevice\x12;.stream.video.coordinator.client_v1_rpc.CreateDeviceRequest\x1a<.stream.video.coordinator.client_v1_rpc.CreateDeviceResponse\x12\x89\x01\n\x0c\x44\x65leteDevice\x12;.stream.video.coordinator.client_v1_rpc.DeleteDeviceRequest\x1a<.stream.video.coordinator.client_v1_rpc.DeleteDeviceResponse\x12\x89\x01\n\x0cQueryDevices\x12;.stream.video.coordinator.client_v1_rpc.QueryDevicesRequest\x1a<.stream.video.coordinator.client_v1_rpc.QueryDevicesResponse\x12\x98\x01\n\x11UpsertCallMembers\x12@.stream.video.coordinator.client_v1_rpc.UpsertCallMembersRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.UpsertCallMembersResponse\x12\x98\x01\n\x11\x44\x65leteCallMembers\x12@.stream.video.coordinator.client_v1_rpc.DeleteCallMembersRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.DeleteCallMembersResponse\x12\x80\x01\n\tSendEvent\x12\x38.stream.video.coordinator.client_v1_rpc.SendEventRequest\x1a\x39.stream.video.coordinator.client_v1_rpc.SendEventResponse\x12\x92\x01\n\x0fSendCustomEvent\x12>.stream.video.coordinator.client_v1_rpc.SendCustomEventRequest\x1a?.stream.video.coordinator.client_v1_rpc.SendCustomEventResponse\x12\x92\x01\n\x0fReportCallStats\x12>.stream.video.coordinator.client_v1_rpc.ReportCallStatsRequest\x1a?.stream.video.coordinator.client_v1_rpc.ReportCallStatsResponse\x12\x9e\x01\n\x13ReportCallStatEvent\x12\x42.stream.video.coordinator.client_v1_rpc.ReportCallStatEventRequest\x1a\x43.stream.video.coordinator.client_v1_rpc.ReportCallStatEventResponse\x12\x83\x01\n\nReviewCall\x12\x39.stream.video.coordinator.client_v1_rpc.ReviewCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.ReviewCallResponse\x12\x86\x01\n\x0bReportIssue\x12:.stream.video.coordinator.client_v1_rpc.ReportIssueRequest\x1a;.stream.video.coordinator.client_v1_rpc.ReportIssueResponseB:B\x0b\x43lientV1RPCZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.client_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013ClientV1RPCZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _USEREVENTTYPE._serialized_start=3920
  _USEREVENTTYPE._serialized_end=4074
  _GETCALLREQUEST._serialized_start=366
  _GETCALLREQUEST._serialized_end=400
  _GETCALLRESPONSE._serialized_start=402
  _GETCALLRESPONSE._serialized_end=487
  _MEMBERINPUT._serialized_start=489
  _MEMBERINPUT._serialized_end=554
  _UPSERTCALLMEMBERSREQUEST._serialized_start=557
  _UPSERTCALLMEMBERSREQUEST._serialized_end=685
  _UPSERTCALLMEMBERSRESPONSE._serialized_start=687
  _UPSERTCALLMEMBERSRESPONSE._serialized_end=714
  _DELETECALLMEMBERSREQUEST._serialized_start=716
  _DELETECALLMEMBERSREQUEST._serialized_end=778
  _DELETECALLMEMBERSRESPONSE._serialized_start=780
  _DELETECALLMEMBERSRESPONSE._serialized_end=807
  _CREATECALLINPUT._serialized_start=810
  _CREATECALLINPUT._serialized_end=990
  _CREATECALLREQUEST._serialized_start=993
  _CREATECALLREQUEST._serialized_end=1122
  _GETORCREATECALLREQUEST._serialized_start=1124
  _GETORCREATECALLREQUEST._serialized_end=1246
  _JOINCALLREQUEST._serialized_start=1249
  _JOINCALLREQUEST._serialized_end=1387
  _JOINCALLRESPONSE._serialized_start=1390
  _JOINCALLRESPONSE._serialized_end=1548
  _CALLINPUT._serialized_start=1550
  _CALLINPUT._serialized_end=1646
  _GETORCREATECALLRESPONSE._serialized_start=1648
  _GETORCREATECALLRESPONSE._serialized_end=1758
  _UPDATECALLREQUEST._serialized_start=1760
  _UPDATECALLREQUEST._serialized_end=1863
  _UPDATECALLRESPONSE._serialized_start=1865
  _UPDATECALLRESPONSE._serialized_end=1953
  _CREATECALLRESPONSE._serialized_start=1955
  _CREATECALLRESPONSE._serialized_end=2043
  _QUERYCALLSREQUEST._serialized_start=2045
  _QUERYCALLSREQUEST._serialized_end=2167
  _QUERYCALLSRESPONSE._serialized_start=2169
  _QUERYCALLSRESPONSE._serialized_end=2259
  _QUERYMEMBERSREQUEST._serialized_start=2261
  _QUERYMEMBERSREQUEST._serialized_end=2385
  _QUERYMEMBERSRESPONSE._serialized_start=2387
  _QUERYMEMBERSRESPONSE._serialized_end=2483
  _GETCALLEDGESERVERREQUEST._serialized_start=2485
  _GETCALLEDGESERVERREQUEST._serialized_end=2606
  _GETCALLEDGESERVERRESPONSE._serialized_start=2609
  _GETCALLEDGESERVERRESPONSE._serialized_end=2772
  _CREATEDEVICEREQUEST._serialized_start=2774
  _CREATEDEVICEREQUEST._serialized_end=2857
  _CREATEDEVICERESPONSE._serialized_start=2859
  _CREATEDEVICERESPONSE._serialized_end=2939
  _DELETEDEVICEREQUEST._serialized_start=2941
  _DELETEDEVICEREQUEST._serialized_end=2974
  _DELETEDEVICERESPONSE._serialized_start=2976
  _DELETEDEVICERESPONSE._serialized_end=2998
  _QUERYDEVICESREQUEST._serialized_start=3000
  _QUERYDEVICESREQUEST._serialized_end=3021
  _QUERYDEVICESRESPONSE._serialized_start=3023
  _QUERYDEVICESRESPONSE._serialized_end=3104
  _SENDEVENTREQUEST._serialized_start=3106
  _SENDEVENTREQUEST._serialized_end=3217
  _SENDEVENTRESPONSE._serialized_start=3219
  _SENDEVENTRESPONSE._serialized_end=3238
  _SENDCUSTOMEVENTREQUEST._serialized_start=3240
  _SENDCUSTOMEVENTREQUEST._serialized_end=3315
  _SENDCUSTOMEVENTRESPONSE._serialized_start=3317
  _SENDCUSTOMEVENTRESPONSE._serialized_end=3342
  _REPORTCALLSTATSREQUEST._serialized_start=3344
  _REPORTCALLSTATSREQUEST._serialized_end=3406
  _REPORTCALLSTATSRESPONSE._serialized_start=3408
  _REPORTCALLSTATSRESPONSE._serialized_end=3433
  _REPORTCALLSTATEVENTREQUEST._serialized_start=3436
  _REPORTCALLSTATEVENTREQUEST._serialized_end=3622
  _REPORTCALLSTATEVENTRESPONSE._serialized_start=3624
  _REPORTCALLSTATEVENTRESPONSE._serialized_end=3653
  _GETCALLSTATSREQUEST._serialized_start=3655
  _GETCALLSTATSREQUEST._serialized_end=3694
  _REPORTISSUEREQUEST._serialized_start=3696
  _REPORTISSUEREQUEST._serialized_end=3776
  _REPORTISSUERESPONSE._serialized_start=3778
  _REPORTISSUERESPONSE._serialized_end=3799
  _REVIEWCALLREQUEST._serialized_start=3801
  _REVIEWCALLREQUEST._serialized_end=3895
  _REVIEWCALLRESPONSE._serialized_start=3897
  _REVIEWCALLRESPONSE._serialized_end=3917
  _CLIENTRPC._serialized_start=4077
  _CLIENTRPC._serialized_end=6652
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/coordinator/broadcast_v1/broadcast.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/stat_v1/stat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/stat_v1/stat.proto\x12 stream.video.coordinator.stat_v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\x16\n\x14ParticipantConnected\"\x19\n\x17ParticipantDisconnected\"\x90\x01\n\x06\x46reeze\x12?\n\nmedia_type\x18\x01 \x01(\x0e\x32+.stream.video.coordinator.stat_v1.MediaType\x12\x18\n\x07peer_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa7\x02\n\x11MediaStateChanged\x12?\n\nmedia_type\x18\x01 \x01(\x0e\x32+.stream.video.coordinator.stat_v1.MediaType\x12\x42\n\x06\x63hange\x18\x02 \x01(\x0e\x32\x32.stream.video.coordinator.stat_v1.MediaStateChange\x12\x43\n\tdirection\x18\x03 \x01(\x0e\x32\x30.stream.video.coordinator.stat_v1.MediaDirection\x12H\n\x06reason\x18\x04 \x01(\x0e\x32\x38.stream.video.coordinator.stat_v1.MediaStateChangeReason\"\x90\x03\n\x0eTelemetryEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12W\n\x15participant_connected\x18\x02 \x01(\x0b\x32\x36.stream.video.coordinator.stat_v1.ParticipantConnectedH\x00\x12]\n\x18participant_disconnected\x18\x03 \x01(\x0b\x32\x39.stream.video.coordinator.stat_v1.ParticipantDisconnectedH\x00\x12R\n\x13media_state_changed\x18\x04 \x01(\x0b\x32\x33.stream.video.coordinator.stat_v1.MediaStateChangedH\x00\x12:\n\x06\x66reeze\x18\x05 \x01(\x0b\x32(.stream.video.coordinator.stat_v1.FreezeH\x00\x42\x07\n\x05\x65vent\"\x92\x01\n\x17\x43\x61llParticipantTimeline\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\nsession_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x30.stream.video.coordinator.stat_v1.TelemetryEvent*S\n\tMediaType\x12\x1a\n\x16MEDIA_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10MEDIA_TYPE_AUDIO\x10\x01\x12\x14\n\x10MEDIA_TYPE_VIDEO\x10\x02*t\n\x10MediaStateChange\x12\"\n\x1eMEDIA_STATE_CHANGE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMEDIA_STATE_CHANGE_STARTED\x10\x01\x12\x1c\n\x18MEDIA_STATE_CHANGE_ENDED\x10\x02*h\n\x0eMediaDirection\x12\x1f\n\x1bMEDIA_DIRECTION_UNSPECIFIED\x10\x00\x12\x18\n\x14MEDIA_DIRECTION_SEND\x10\x01\x12\x1b\n\x17MEDIA_DIRECTION_RECEIVE\x10\x02*\x91\x01\n\x16MediaStateChangeReason\x12)\n%MEDIA_STATE_CHANGE_REASON_UNSPECIFIED\x10\x00\x12\"\n\x1eMEDIA_STATE_CHANGE_REASON_MUTE\x10\x01\x12(\n$MEDIA_STATE_CHANGE_REASON_CONNECTION\x10\x02\x42\x31\x42\x06StatV1P\x01Z\x07stat_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.stat_v1.stat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006StatV1P\001Z\007stat_v1\252\002\033Stream.Video.v1.Coordinator'
  _FREEZE.fields_by_name['peer_id']._options = None
  _FREEZE.fields_by_name['peer_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLPARTICIPANTTIMELINE.fields_by_name['user_id']._options = None
  _CALLPARTICIPANTTIMELINE.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLPARTICIPANTTIMELINE.fields_by_name['session_id']._options = None
  _CALLPARTICIPANTTIMELINE.fields_by_name['session_id']._serialized_options = b'\372B\004r\002\020\001'
  _MEDIATYPE._serialized_start=1212
  _MEDIATYPE._serialized_end=1295
  _MEDIASTATECHANGE._serialized_start=1297
  _MEDIASTATECHANGE._serialized_end=1413
  _MEDIADIRECTION._serialized_start=1415
  _MEDIADIRECTION._serialized_end=1519
  _MEDIASTATECHANGEREASON._serialized_start=1522
  _MEDIASTATECHANGEREASON._serialized_end=1667
  _PARTICIPANTCONNECTED._serialized_start=164
  _PARTICIPANTCONNECTED._serialized_end=186
  _PARTICIPANTDISCONNECTED._serialized_start=188
  _PARTICIPANTDISCONNECTED._serialized_end=213
  _FREEZE._serialized_start=216
  _FREEZE._serialized_end=360
  _MEDIASTATECHANGED._serialized_start=363
  _MEDIASTATECHANGED._serialized_end=658
  _TELEMETRYEVENT._serialized_start=661
  _TELEMETRYEVENT._serialized_end=1061
  _CALLPARTICIPANTTIMELINE._serialized_start=1064
  _CALLPARTICIPANTTIMELINE._serialized_end=1210
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _E:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_E.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSPECIFIED: _E.ValueType  # 0
    """Error code is not specified"""
    AUTH_TOKEN_INVALID: _E.ValueType  # 1001
    """10xx - auth token errors

    Authentication token is invalid. This code is returned if none of specific error codes match
    """
    AUTH_TOKEN_NOT_VALID_YET: _E.ValueType  # 1002
    """Authentication token is not valid yet (`nbf` claim)"""
    AUTH_TOKEN_USED_BEFORE_ISSUE: _E.ValueType  # 1003
    """Authentication token is used before its issue date (`iat` claim)"""
    AUTH_TOKEN_EXPIRED: _E.ValueType  # 1004
    """Authentication token is expired (`exp` claim)"""
    AUTH_TOKEN_INVALID_SIGNATURE: _E.ValueType  # 1005
    """Authentication token has invalid signature"""
    API_KEY_NOT_PROVIDED: _E.ValueType  # 1101
    """11xx - API key errors

    API key is not provided
    """
    API_KEY_IS_UNKNOWN: _E.ValueType  # 1102
    """Unknown API key is provided"""
    PERMISSION_DENIED: _E.ValueType  # 1201
    """12xx - Permission errors

    Permission was denied
    """
    REQUEST_VALIDATION_FAILED: _E.ValueType  # 1301
    """13xx - validation errors

    Request validation failed
    """
    CALL_TYPE_NOT_FOUND: _E.ValueType  # 1401
    """14xx - Call type errors

    CallType was not found
    """
    CALL_TYPE_ALREADY_EXISTS: _E.ValueType  # 1403
    """RoomType already exists"""
    CALL_NOT_FOUND: _E.ValueType  # 1501
    """15xx - Call errors"""
    CALL_ALREADY_EXISTS: _E.ValueType  # 1502
    PUSH_PROVIDER_NOT_FOUND: _E.ValueType  # 1601
    """16xx - Push errors"""
    PUSH_DEVICE_NOT_FOUND: _E.ValueType  # 1602
    USER_NOT_FOUND: _E.ValueType  # 1701
    """17xx - User errors"""
    USER_ALREADY_EXISTS: _E.ValueType  # 1702
    SFU_NO_DATACENTERS_AVAILABLE: _E.ValueType  # 1801
    """18xx - SFU errors"""

class E(_E, metaclass=_EEnumTypeWrapper):
    """E defines all API error codes that client can receive
    Not to be confused with Twirp error codes. Most of API errors will produce `invalid_argument` Twirp error,
    but some are mapped to more specific ones like `permission_denied` or `not_found`.
    Keep the distance of `100` between error domains, so more errors can be added in the future.
    Do not use `xxx0` codes
    Do not prefix const values with  in this enum. This proto package only contains one enum which guarantees lack of name collision.
    When the prefix is used, Go generator creates consts with E_ERROR_* which we want to avoid here
    protolint:disable:next ENUM_FIELD_NAMES_PREFIX
    """

UNSPECIFIED: E.ValueType  # 0
"""Error code is not specified"""
AUTH_TOKEN_INVALID: E.ValueType  # 1001
"""10xx - auth token errors

Authentication token is invalid. This code is returned if none of specific error codes match
"""
AUTH_TOKEN_NOT_VALID_YET: E.ValueType  # 1002
"""Authentication token is not valid yet (`nbf` claim)"""
AUTH_TOKEN_USED_BEFORE_ISSUE: E.ValueType  # 1003
"""Authentication token is used before its issue date (`iat` claim)"""
AUTH_TOKEN_EXPIRED: E.ValueType  # 1004
"""Authentication token is expired (`exp` claim)"""
AUTH_TOKEN_INVALID_SIGNATURE: E.ValueType  # 1005
"""Authentication token has invalid signature"""
API_KEY_NOT_PROVIDED: E.ValueType  # 1101
"""11xx - API key errors

API key is not provided
"""
API_KEY_IS_UNKNOWN: E.ValueType  # 1102
"""Unknown API key is provided"""
PERMISSION_DENIED: E.ValueType  # 1201
"""12xx - Permission errors

Permission was denied
"""
REQUEST_VALIDATION_FAILED: E.ValueType  # 1301
"""13xx - validation errors

Request validation failed
"""
CALL_TYPE_NOT_FOUND: E.ValueType  # 1401
"""14xx - Call type errors

CallType was not found
"""
CALL_TYPE_ALREADY_EXISTS: E.ValueType  # 1403
"""RoomType already exists"""
CALL_NOT_FOUND: E.ValueType  # 1501
"""15xx - Call errors"""
CALL_ALREADY_EXISTS: E.ValueType  # 1502
PUSH_PROVIDER_NOT_FOUND: E.ValueType  # 1601
"""16xx - Push errors"""
PUSH_DEVICE_NOT_FOUND: E.ValueType  # 1602
USER_NOT_FOUND: E.ValueType  # 1701
"""17xx - User errors"""
USER_ALREADY_EXISTS: E.ValueType  # 1702
SFU_NO_DATACENTERS_AVAILABLE: E.ValueType  # 1801
"""18xx - SFU errors"""
global___E = E



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import video.coordinator.event_v1.event_pb2
import video.coordinator.push_v1.push_pb2
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class WebsocketEvent(google.protobuf.message.Message):
    """WebsocketEvent only includes events that are sent to the client via websocket connection
    This is not an exhaustive list of events, since not all of them are sent via websocket
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.user_v1.user_pb2.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.user_v1.user_pb2.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    HEALTHCHECK_FIELD_NUMBER: builtins.int
    CALL_CREATED_FIELD_NUMBER: builtins.int
    CALL_UPDATED_FIELD_NUMBER: builtins.int
    CALL_DELETED_FIELD_NUMBER: builtins.int
    CALL_MEMBERS_CREATED_FIELD_NUMBER: builtins.int
    CALL_MEMBERS_UPDATED_FIELD_NUMBER: builtins.int
    CALL_MEMBERS_DELETED_FIELD_NUMBER: builtins.int
    CALL_ENDED_FIELD_NUMBER: builtins.int
    CALL_ACCEPTED_FIELD_NUMBER: builtins.int
    CALL_REJECTED_FIELD_NUMBER: builtins.int
    CALL_CANCELLED_FIELD_NUMBER: builtins.int
    USER_UPDATED_FIELD_NUMBER: builtins.int
    CALL_CUSTOM_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.user_v1.user_pb2.User]:
        """All users mentioned in the event payload, indexed by User.id"""
    @property
    def healthcheck(self) -> global___WebsocketHealthcheck: ...
    @property
    def call_created(self) -> video.coordinator.event_v1.event_pb2.CallCreated:
        """Call events"""
    @property
    def call_updated(self) -> video.coordinator.event_v1.event_pb2.CallUpdated: ...
    @property
    def call_deleted(self) -> video.coordinator.event_v1.event_pb2.CallDeleted: ...
    @property
    def call_members_created(self) -> video.coordinator.event_v1.event_pb2.CallMembersCreated: ...
    @property
    def call_members_updated(self) -> video.coordinator.event_v1.event_pb2.CallMembersUpdated: ...
    @property
    def call_members_deleted(self) -> video.coordinator.event_v1.event_pb2.CallMembersDeleted: ...
    @property
    def call_ended(self) -> video.coordinator.event_v1.event_pb2.CallEnded: ...
    @property
    def call_accepted(self) -> video.coordinator.event_v1.event_pb2.CallAccepted:
        """User initiated call events"""
    @property
    def call_rejected(self) -> video.coordinator.event_v1.event_pb2.CallRejected: ...
    @property
    def call_cancelled(self) -> video.coordinator.event_v1.event_pb2.CallCancelled: ...
    @property
    def user_updated(self) -> video.coordinator.event_v1.event_pb2.UserUpdated:
        """User events"""
    @property
    def call_custom(self) -> video.coordinator.event_v1.event_pb2.CallCustom:
        """Custom event"""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, video.coordinator.user_v1.user_pb2.User] | None = ...,
        healthcheck: global___WebsocketHealthcheck | None = ...,
        call_created: video.coordinator.event_v1.event_pb2.CallCreated | None = ...,
        call_updated: video.coordinator.event_v1.event_pb2.CallUpdated | None = ...,
        call_deleted: video.coordinator.event_v1.event_pb2.CallDeleted | None = ...,
        call_members_created: video.coordinator.event_v1.event_pb2.CallMembersCreated | None = ...,
        call_members_updated: video.coordinator.event_v1.event_pb2.CallMembersUpdated | None = ...,
        call_members_deleted: video.coordinator.event_v1.event_pb2.CallMembersDeleted | None = ...,
        call_ended: video.coordinator.event_v1.event_pb2.CallEnded | None = ...,
        call_accepted: video.coordinator.event_v1.event_pb2.CallAccepted | None = ...,
        call_rejected: video.coordinator.event_v1.event_pb2.CallRejected | None = ...,
        call_cancelled: video.coordinator.event_v1.event_pb2.CallCancelled | None = ...,
        user_updated: video.coordinator.event_v1.event_pb2.UserUpdated | None = ...,
        call_custom: video.coordinator.event_v1.event_pb2.CallCustom | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call_accepted", b"call_accepted", "call_cancelled", b"call_cancelled", "call_created", b"call_created", "call_custom", b"call_custom", "call_deleted", b"call_deleted", "call_ended", b"call_ended", "call_members_created", b"call_members_created", "call_members_deleted", b"call_members_deleted", "call_members_updated", b"call_members_updated", "call_rejected", b"call_rejected", "call_updated", b"call_updated", "event", b"event", "healthcheck", b"healthcheck", "user_updated", b"user_updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_accepted", b"call_accepted", "call_cancelled", b"call_cancelled", "call_created", b"call_created", "call_custom", b"call_custom", "call_deleted", b"call_deleted", "call_ended", b"call_ended", "call_members_created", b"call_members_created", "call_members_deleted", b"call_members_deleted", "call_members_updated", b"call_members_updated", "call_rejected", b"call_rejected", "call_updated", b"call_updated", "event", b"event", "healthcheck", b"healthcheck", "user_updated", b"user_updated", "users", b"users"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["healthcheck", "call_created", "call_updated", "call_deleted", "call_members_created", "call_members_updated", "call_members_deleted", "call_ended", "call_accepted", "call_rejected", "call_cancelled", "user_updated", "call_custom"] | None: ...

global___WebsocketEvent = WebsocketEvent

class WebsocketClientEvent(google.protobuf.message.Message):
    """WebsocketClientEvent contains all events that client is allowed to send to the server
    When clients sends any of mentioned events, they should be wrapped into ClientEvent
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTHCHECK_FIELD_NUMBER: builtins.int
    AUTH_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def healthcheck(self) -> global___WebsocketHealthcheck: ...
    @property
    def auth_request(self) -> global___WebsocketAuthRequest: ...
    def __init__(
        self,
        *,
        healthcheck: global___WebsocketHealthcheck | None = ...,
        auth_request: global___WebsocketAuthRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_request", b"auth_request", "event", b"event", "healthcheck", b"healthcheck"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_request", b"auth_request", "event", b"event", "healthcheck", b"healthcheck"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["healthcheck", "auth_request"] | None: ...

global___WebsocketClientEvent = WebsocketClientEvent

class WebsocketAuthRequest(google.protobuf.message.Message):
    """A payload that is sent through websocket to authenticate a connection"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    """Application API key that matches a secret is used to sign a token"""
    token: builtins.str
    """A client JWT token"""
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.UserInput:
        """Optional UserInput. When present, it is used to create or update user information.
        If contains some changes, a permission check will be performed
        """
    @property
    def device(self) -> video.coordinator.push_v1.push_pb2.DeviceInput:
        """Optional DeviceInput. When present, a device will be created for a user. If device
        already exists, nothing will happen
        """
    def __init__(
        self,
        *,
        api_key: builtins.str = ...,
        token: builtins.str = ...,
        user: video.coordinator.user_v1.user_pb2.UserInput | None = ...,
        device: video.coordinator.push_v1.push_pb2.DeviceInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["device", b"device", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "device", b"device", "token", b"token", "user", b"user"]) -> None: ...

global___WebsocketAuthRequest = WebsocketAuthRequest

class WebsocketHealthcheck(google.protobuf.message.Message):
    """Healthcheck is sent back and forth between websocket client and server
    When server sends a healthcheck, it is wrapped into WebsocketEvent
    When client sends healthcheck, it should be wrapped into WebsocketClientEvent
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CALL_TYPE_FIELD_NUMBER: builtins.int
    CALL_ID_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    client_id: builtins.str
    call_type: builtins.str
    call_id: builtins.str
    video: builtins.bool
    audio: builtins.bool
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        client_id: builtins.str = ...,
        call_type: builtins.str = ...,
        call_id: builtins.str = ...,
        video: builtins.bool = ...,
        audio: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "call_id", b"call_id", "call_type", b"call_type", "client_id", b"client_id", "user_id", b"user_id", "video", b"video"]) -> None: ...

global___WebsocketHealthcheck = WebsocketHealthcheck



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import video.sfu.models.models_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SfuEvent(google.protobuf.message.Message):
    """SFUEvent is a message that is sent from the SFU to the client."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIBER_OFFER_FIELD_NUMBER: builtins.int
    PUBLISHER_ANSWER_FIELD_NUMBER: builtins.int
    CONNECTION_QUALITY_CHANGED_FIELD_NUMBER: builtins.int
    AUDIO_LEVEL_CHANGED_FIELD_NUMBER: builtins.int
    ICE_TRICKLE_FIELD_NUMBER: builtins.int
    CHANGE_PUBLISH_QUALITY_FIELD_NUMBER: builtins.int
    LOCAL_DEVICE_CHANGE_FIELD_NUMBER: builtins.int
    MUTE_STATE_CHANGED_FIELD_NUMBER: builtins.int
    VIDEO_QUALITY_CHANGED_FIELD_NUMBER: builtins.int
    PARTICIPANT_JOINED_FIELD_NUMBER: builtins.int
    PARTICIPANT_LEFT_FIELD_NUMBER: builtins.int
    DOMINANT_SPEAKER_CHANGED_FIELD_NUMBER: builtins.int
    JOIN_RESPONSE_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def subscriber_offer(self) -> global___SubscriberOffer: ...
    @property
    def publisher_answer(self) -> global___PublisherAnswer: ...
    @property
    def connection_quality_changed(self) -> global___ConnectionQualityChanged: ...
    @property
    def audio_level_changed(self) -> global___AudioLevelChanged: ...
    @property
    def ice_trickle(self) -> video.sfu.models.models_pb2.ICETrickle: ...
    @property
    def change_publish_quality(self) -> global___ChangePublishQuality: ...
    @property
    def local_device_change(self) -> global___LocalDeviceChange: ...
    @property
    def mute_state_changed(self) -> global___MuteStateChanged: ...
    @property
    def video_quality_changed(self) -> global___VideoQualityChanged: ...
    @property
    def participant_joined(self) -> global___ParticipantJoined: ...
    @property
    def participant_left(self) -> global___ParticipantLeft: ...
    @property
    def dominant_speaker_changed(self) -> global___DominantSpeakerChanged: ...
    @property
    def join_response(self) -> global___JoinResponse: ...
    @property
    def health_check_response(self) -> global___HealthCheckResponse: ...
    def __init__(
        self,
        *,
        subscriber_offer: global___SubscriberOffer | None = ...,
        publisher_answer: global___PublisherAnswer | None = ...,
        connection_quality_changed: global___ConnectionQualityChanged | None = ...,
        audio_level_changed: global___AudioLevelChanged | None = ...,
        ice_trickle: video.sfu.models.models_pb2.ICETrickle | None = ...,
        change_publish_quality: global___ChangePublishQuality | None = ...,
        local_device_change: global___LocalDeviceChange | None = ...,
        mute_state_changed: global___MuteStateChanged | None = ...,
        video_quality_changed: global___VideoQualityChanged | None = ...,
        participant_joined: global___ParticipantJoined | None = ...,
        participant_left: global___ParticipantLeft | None = ...,
        dominant_speaker_changed: global___DominantSpeakerChanged | None = ...,
        join_response: global___JoinResponse | None = ...,
        health_check_response: global___HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio_level_changed", b"audio_level_changed", "change_publish_quality", b"change_publish_quality", "connection_quality_changed", b"connection_quality_changed", "dominant_speaker_changed", b"dominant_speaker_changed", "event_payload", b"event_payload", "health_check_response", b"health_check_response", "ice_trickle", b"ice_trickle", "join_response", b"join_response", "local_device_change", b"local_device_change", "mute_state_changed", b"mute_state_changed", "participant_joined", b"participant_joined", "participant_left", b"participant_left", "publisher_answer", b"publisher_answer", "subscriber_offer", b"subscriber_offer", "video_quality_changed", b"video_quality_changed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_level_changed", b"audio_level_changed", "change_publish_quality", b"change_publish_quality", "connection_quality_changed", b"connection_quality_changed", "dominant_speaker_changed", b"dominant_speaker_changed", "event_payload", b"event_payload", "health_check_response", b"health_check_response", "ice_trickle", b"ice_trickle", "join_response", b"join_response", "local_device_change", b"local_device_change", "mute_state_changed", b"mute_state_changed", "participant_joined", b"participant_joined", "participant_left", b"participant_left", "publisher_answer", b"publisher_answer", "subscriber_offer", b"subscriber_offer", "video_quality_changed", b"video_quality_changed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event_payload", b"event_payload"]) -> typing_extensions.Literal["subscriber_offer", "publisher_answer", "connection_quality_changed", "audio_level_changed", "ice_trickle", "change_publish_quality", "local_device_change", "mute_state_changed", "video_quality_changed", "participant_joined", "participant_left", "dominant_speaker_changed", "join_response", "health_check_response"] | None: ...

global___SfuEvent = SfuEvent

class SfuRequest(google.protobuf.message.Message):
    """SfuRequest is a message that is sent from the client to the SFU."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOIN_REQUEST_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def join_request(self) -> global___JoinRequest: ...
    @property
    def health_check_request(self) -> global___HealthCheckRequest: ...
    def __init__(
        self,
        *,
        join_request: global___JoinRequest | None = ...,
        health_check_request: global___HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_request", b"health_check_request", "join_request", b"join_request", "request_payload", b"request_payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_request", b"health_check_request", "join_request", b"join_request", "request_payload", b"request_payload"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["request_payload", b"request_payload"]) -> typing_extensions.Literal["join_request", "health_check_request"] | None: ...

global___SfuRequest = SfuRequest

class HealthCheckRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_id", b"session_id"]) -> None: ...

global___HealthCheckRequest = HealthCheckRequest

class HealthCheckResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_id", b"session_id"]) -> None: ...

global___HealthCheckResponse = HealthCheckResponse

class JoinRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    CODEC_SETTINGS_FIELD_NUMBER: builtins.int
    token: builtins.str
    session_id: builtins.str
    publish: builtins.bool
    @property
    def codec_settings(self) -> video.sfu.models.models_pb2.CodecSettings:
        """TODO: we should know if this is going to be
        - publishing and subscribing, or just subscribing for future routing
        """
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        session_id: builtins.str = ...,
        publish: builtins.bool = ...,
        codec_settings: video.sfu.models.models_pb2.CodecSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["codec_settings", b"codec_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["codec_settings", b"codec_settings", "publish", b"publish", "session_id", b"session_id", "token", b"token"]) -> None: ...

global___JoinRequest = JoinRequest

class JoinResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_STATE_FIELD_NUMBER: builtins.int
    OWN_SESSION_ID_FIELD_NUMBER: builtins.int
    @property
    def call_state(self) -> video.sfu.models.models_pb2.CallState: ...
    own_session_id: builtins.str
    """TODO: include full list of participants with track and audio info"""
    def __init__(
        self,
        *,
        call_state: video.sfu.models.models_pb2.CallState | None = ...,
        own_session_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call_state", b"call_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_state", b"call_state", "own_session_id", b"own_session_id"]) -> None: ...

global___JoinResponse = JoinResponse

class ParticipantJoined(google.protobuf.message.Message):
    """ParticipantJoined is fired when a user joins a call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.sfu.models.models_pb2.Call: ...
    @property
    def participant(self) -> video.sfu.models.models_pb2.Participant: ...
    def __init__(
        self,
        *,
        call: video.sfu.models.models_pb2.Call | None = ...,
        participant: video.sfu.models.models_pb2.Participant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "participant", b"participant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "participant", b"participant"]) -> None: ...

global___ParticipantJoined = ParticipantJoined

class ParticipantLeft(google.protobuf.message.Message):
    """ParticipantJoined is fired when a user leaves a call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.sfu.models.models_pb2.Call: ...
    @property
    def participant(self) -> video.sfu.models.models_pb2.Participant: ...
    def __init__(
        self,
        *,
        call: video.sfu.models.models_pb2.Call | None = ...,
        participant: video.sfu.models.models_pb2.Participant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "participant", b"participant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "participant", b"participant"]) -> None: ...

global___ParticipantLeft = ParticipantLeft

class MuteStateChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    AUDIO_MUTED_FIELD_NUMBER: builtins.int
    VIDEO_MUTED_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    audio_muted: builtins.bool
    video_muted: builtins.bool
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        audio_muted: builtins.bool = ...,
        video_muted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_muted", b"audio_muted", "user_id", b"user_id", "video_muted", b"video_muted"]) -> None: ...

global___MuteStateChanged = MuteStateChanged

class VideoQualityChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_QUALITIES_FIELD_NUMBER: builtins.int
    @property
    def stream_qualities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.sfu.models.models_pb2.StreamQuality]: ...
    def __init__(
        self,
        *,
        stream_qualities: collections.abc.Iterable[video.sfu.models.models_pb2.StreamQuality] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stream_qualities", b"stream_qualities"]) -> None: ...

global___VideoQualityChanged = VideoQualityChanged

class SubscriberOffer(google.protobuf.message.Message):
    """SubscriberOffer is sent when the SFU adds tracks to a subscription
    this usually happens when a user joins a call and starts sending video
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_FIELD_NUMBER: builtins.int
    sdp: builtins.str
    def __init__(
        self,
        *,
        sdp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp", b"sdp"]) -> None: ...

global___SubscriberOffer = SubscriberOffer

class PublisherAnswer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_FIELD_NUMBER: builtins.int
    sdp: builtins.str
    def __init__(
        self,
        *,
        sdp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp", b"sdp"]) -> None: ...

global___PublisherAnswer = PublisherAnswer

class LocalDeviceChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___LocalDeviceChange = LocalDeviceChange

class ICECandidateTrickle(google.protobuf.message.Message):
    """ICECandidateTrickle is about the ICE nonsense stuff"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANDIDATE_FIELD_NUMBER: builtins.int
    candidate: builtins.str
    def __init__(
        self,
        *,
        candidate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["candidate", b"candidate"]) -> None: ...

global___ICECandidateTrickle = ICECandidateTrickle

class ConnectionQualityChanged(google.protobuf.message.Message):
    """ConnectionQuality is sent to inform about connection quality changes
    eg. thierry's connection is not good -> render a red icon Zoom style
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    CONNECTION_QUALITY_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    connection_quality: video.sfu.models.models_pb2.ConnectionQuality.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        connection_quality: video.sfu.models.models_pb2.ConnectionQuality.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_quality", b"connection_quality", "user_id", b"user_id"]) -> None: ...

global___ConnectionQualityChanged = ConnectionQualityChanged

class DominantSpeakerChanged(google.protobuf.message.Message):
    """DominantSpeakerChanged is sent by the SFU to notify when there is a new dominant speaker in the call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___DominantSpeakerChanged = DominantSpeakerChanged

class AudioLevelChanged(google.protobuf.message.Message):
    """AudioLevelChanged is sent by the SFU to notify about audio levels by user"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def audio_levels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioLevel]: ...
    def __init__(
        self,
        *,
        audio_levels: collections.abc.Iterable[global___AudioLevel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_levels", b"audio_levels"]) -> None: ...

global___AudioLevelChanged = AudioLevelChanged

class AudioLevel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    level: builtins.float
    """0.0 means complete silence, 1.0 loudest"""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        level: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["level", b"level", "user_id", b"user_id"]) -> None: ...

global___AudioLevel = AudioLevel

class AudioLayerSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AudioLayerSetting = AudioLayerSetting

class AudioMediaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_COUNT_FIELD_NUMBER: builtins.int
    channel_count: builtins.int
    def __init__(
        self,
        *,
        channel_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_count", b"channel_count"]) -> None: ...

global___AudioMediaRequest = AudioMediaRequest

class AudioSender(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_REQUEST_FIELD_NUMBER: builtins.int
    CODEC_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    @property
    def media_request(self) -> global___AudioMediaRequest: ...
    @property
    def codec(self) -> video.sfu.models.models_pb2.Codec: ...
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioLayerSetting]: ...
    def __init__(
        self,
        *,
        media_request: global___AudioMediaRequest | None = ...,
        codec: video.sfu.models.models_pb2.Codec | None = ...,
        layers: collections.abc.Iterable[global___AudioLayerSetting] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["codec", b"codec", "media_request", b"media_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["codec", b"codec", "layers", b"layers", "media_request", b"media_request"]) -> None: ...

global___AudioSender = AudioSender

class VideoMediaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDEAL_HEIGHT_FIELD_NUMBER: builtins.int
    IDEAL_WIDTH_FIELD_NUMBER: builtins.int
    IDEAL_FRAME_RATE_FIELD_NUMBER: builtins.int
    ideal_height: builtins.int
    ideal_width: builtins.int
    ideal_frame_rate: builtins.int
    def __init__(
        self,
        *,
        ideal_height: builtins.int = ...,
        ideal_width: builtins.int = ...,
        ideal_frame_rate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ideal_frame_rate", b"ideal_frame_rate", "ideal_height", b"ideal_height", "ideal_width", b"ideal_width"]) -> None: ...

global___VideoMediaRequest = VideoMediaRequest

class VideoLayerSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Priority:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PriorityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VideoLayerSetting._Priority.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIORITY_HIGH_UNSPECIFIED: VideoLayerSetting._Priority.ValueType  # 0
        PRIORITY_LOW: VideoLayerSetting._Priority.ValueType  # 1
        PRIORITY_MEDIUM: VideoLayerSetting._Priority.ValueType  # 2
        PRIORITY_VERY_LOW: VideoLayerSetting._Priority.ValueType  # 3

    class Priority(_Priority, metaclass=_PriorityEnumTypeWrapper): ...
    PRIORITY_HIGH_UNSPECIFIED: VideoLayerSetting.Priority.ValueType  # 0
    PRIORITY_LOW: VideoLayerSetting.Priority.ValueType  # 1
    PRIORITY_MEDIUM: VideoLayerSetting.Priority.ValueType  # 2
    PRIORITY_VERY_LOW: VideoLayerSetting.Priority.ValueType  # 3

    NAME_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    MAX_BITRATE_FIELD_NUMBER: builtins.int
    SCALE_RESOLUTION_DOWN_BY_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    CODEC_FIELD_NUMBER: builtins.int
    name: builtins.str
    active: builtins.bool
    max_bitrate: builtins.int
    scale_resolution_down_by: builtins.float
    priority: global___VideoLayerSetting.Priority.ValueType
    @property
    def codec(self) -> video.sfu.models.models_pb2.Codec: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        active: builtins.bool = ...,
        max_bitrate: builtins.int = ...,
        scale_resolution_down_by: builtins.float = ...,
        priority: global___VideoLayerSetting.Priority.ValueType = ...,
        codec: video.sfu.models.models_pb2.Codec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["codec", b"codec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "codec", b"codec", "max_bitrate", b"max_bitrate", "name", b"name", "priority", b"priority", "scale_resolution_down_by", b"scale_resolution_down_by"]) -> None: ...

global___VideoLayerSetting = VideoLayerSetting

class VideoSender(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_REQUEST_FIELD_NUMBER: builtins.int
    CODEC_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    @property
    def media_request(self) -> global___VideoMediaRequest: ...
    @property
    def codec(self) -> video.sfu.models.models_pb2.Codec: ...
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoLayerSetting]: ...
    def __init__(
        self,
        *,
        media_request: global___VideoMediaRequest | None = ...,
        codec: video.sfu.models.models_pb2.Codec | None = ...,
        layers: collections.abc.Iterable[global___VideoLayerSetting] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["codec", b"codec", "media_request", b"media_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["codec", b"codec", "layers", b"layers", "media_request", b"media_request"]) -> None: ...

global___VideoSender = VideoSender

class ChangePublishQuality(google.protobuf.message.Message):
    """sent to users when they need to change the quality of their video"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_SENDERS_FIELD_NUMBER: builtins.int
    VIDEO_SENDERS_FIELD_NUMBER: builtins.int
    @property
    def audio_senders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioSender]: ...
    @property
    def video_senders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoSender]: ...
    def __init__(
        self,
        *,
        audio_senders: collections.abc.Iterable[global___AudioSender] | None = ...,
        video_senders: collections.abc.Iterable[global___VideoSender] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_senders", b"audio_senders", "video_senders", b"video_senders"]) -> None: ...

global___ChangePublishQuality = ChangePublishQuality



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    id: builtins.int
    @property
    def webhook(self) -> global___WebhookSettings: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        webhook: global___WebhookSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["webhook", b"webhook"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "webhook", b"webhook"]) -> None: ...

global___App = App

class WebhookSettings(google.protobuf.message.Message):
    """Keep in sync with stream.config.webhook.AppSettings"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_FIELD_NUMBER: builtins.int
    SQS_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___HttpWebhook: ...
    @property
    def sqs(self) -> global___SqsWebhook: ...
    def __init__(
        self,
        *,
        http: global___HttpWebhook | None = ...,
        sqs: global___SqsWebhook | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http", b"http", "sqs", b"sqs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http", b"http", "sqs", b"sqs"]) -> None: ...

global___WebhookSettings = WebhookSettings

class HttpWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___HttpWebhook = HttpWebhook

class SqsWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    url: builtins.str
    key: builtins.str
    secret: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        key: builtins.str = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "secret", b"secret", "url", b"url"]) -> None: ...

global___SqsWebhook = SqsWebhook



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/server_v1_rpc/server_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from video.coordinator.app_v1 import app_pb2 as video_dot_coordinator_dot_app__v1_dot_app__pb2
from video.coordinator.broadcast_v1 import broadcast_pb2 as video_dot_coordinator_dot_broadcast__v1_dot_broadcast__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.recording_v1 import recording_pb2 as video_dot_coordinator_dot_recording__v1_dot_recording__pb2
from video.coordinator.server_v1_rpc import envelopes_pb2 as video_dot_coordinator_dot_server__v1__rpc_dot_envelopes__pb2
from video.coordinator.stat_v1 import stat_pb2 as video_dot_coordinator_dot_stat__v1_dot_stat__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0video/coordinator/server_v1_rpc/server_rpc.proto\x12&stream.video.coordinator.server_v1_rpc\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\"video/coordinator/app_v1/app.proto\x1a.video/coordinator/broadcast_v1/broadcast.proto\x1a$video/coordinator/call_v1/call.proto\x1a$video/coordinator/push_v1/push.proto\x1a.video/coordinator/recording_v1/recording.proto\x1a/video/coordinator/server_v1_rpc/envelopes.proto\x1a$video/coordinator/stat_v1/stat.proto\x1a$video/coordinator/user_v1/user.proto\"\x0f\n\rGetAppRequest\"C\n\x0eGetAppResponse\x12\x31\n\x03\x61pp\x18\x01 \x01(\x0b\x32$.stream.video.coordinator.app_v1.App\"U\n\x10UpdateAppRequest\x12\x41\n\x07webhook\x18\x01 \x01(\x0b\x32\x30.stream.video.coordinator.app_v1.WebhookSettings\"F\n\x11UpdateAppResponse\x12\x31\n\x03\x61pp\x18\x01 \x01(\x0b\x32$.stream.video.coordinator.app_v1.App\"\xc8\x02\n\x11PushProviderInput\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x03\x61pn\x18\x02 \x01(\x0b\x32\x30.stream.video.coordinator.push_v1.ApnCredentialsH\x00\x12I\n\x08\x66irebase\x18\x03 \x01(\x0b\x32\x35.stream.video.coordinator.push_v1.FirebaseCredentialsH\x00\x12\x45\n\x06huawei\x18\x04 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.HuaweiCredentialsH\x00\x12\x45\n\x06xiaomi\x18\x05 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.XiaomiCredentialsH\x00\x42\r\n\x0b\x63redentials\"e\n\x19\x43reatePushProviderRequest\x12H\n\x05input\x18\x01 \x01(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.PushProviderInput\"^\n\x1a\x43reatePushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"$\n\x16GetPushProviderRequest\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x17GetPushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"\x1b\n\x19QueryPushProvidersRequest\"_\n\x1aQueryPushProvidersResponse\x12\x41\n\tproviders\x18\x01 \x03(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"e\n\x19UpdatePushProviderRequest\x12H\n\x05input\x18\x01 \x01(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.PushProviderInput\"^\n\x1aUpdatePushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"\'\n\x19\x44\x65letePushProviderRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65letePushProviderResponse\"%\n\x15\x44\x65leteCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteCallTypeResponse\"e\n\x15\x43reateCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"W\n\x16\x43reateCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\"\n\x12GetCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"T\n\x13GetCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\x17\n\x15QueryCallTypesRequest\"X\n\x16QueryCallTypesResponse\x12>\n\ncall_types\x18\x01 \x03(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"e\n\x15UpdateCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"W\n\x16UpdateCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\xab\x02\n\x11\x43reateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\x12\x17\n\x0fparticipant_ids\x18\x04 \x03(\t\x12\x31\n\rhls_broadcast\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x04rtmp\x18\x07 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\x12-\n\trecording\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06notify\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"r\n\x11\x43reateUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05teams\x18\x02 \x03(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\"{\n\x1a\x43reateOrUpdateUsersRequest\x12H\n\x05users\x18\x01 \x03(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.CreateUserRequest\x12\x13\n\x0b\x66ull_update\x18\x02 \x01(\x08\"T\n\x1b\x43reateOrUpdateUsersResponse\x12\x35\n\x05users\x18\x01 \x03(\x0b\x32&.stream.video.coordinator.user_v1.User\"W\n\x11\x44\x65leteUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65lete_call_history\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x65lete_recordings\x18\x03 \x01(\x08\"\x1f\n\x11\x45xportUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x12\x45xportUserResponse\x12O\n\x0b\x65xport_user\x18\x01 \x01(\x0b\x32:.stream.video.coordinator.server_v1_rpc.ExportUserEnvelope\" \n\x12\x44\x65leteUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\"J\n\x12\x43reateUserResponse\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\"5\n\x0eUserCapability\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x94\x01\n\x15StartBroadcastRequest\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\t\x12\x11\n\tcall_type\x18\x02 \x01(\t\x12\x15\n\rhls_broadcast\x18\x03 \x01(\x08\x12@\n\x04rtmp\x18\x05 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\"]\n\x16StartBroadcastResponse\x12\x43\n\tbroadcast\x18\x01 \x01(\x0b\x32\x30.stream.video.coordinator.broadcast_v1.Broadcast\"\x16\n\x14StopBroadcastRequest\"\x17\n\x15StopBroadcastResponse\"\x15\n\x13StoreLatencyRequest\"\x16\n\x14StoreLatencyResponse\";\n\x15StartRecordingRequest\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\"\x18\n\x16StartRecordingResponse\":\n\x14StopRecordingRequest\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\",\n\x15StopRecordingResponse\x12\x13\n\x0bs3_file_url\x18\x01 \x01(\t\"\x16\n\x14GetRecordingsRequest\"]\n\x15GetRecordingsResponse\x12\x44\n\nrecordings\x18\x01 \x03(\x0b\x32\x30.stream.video.coordinator.recording_v1.Recording\"\x18\n\x16\x44\x65leteRecordingRequest\"\x19\n\x17\x44\x65leteRecordingResponse\"\x92\x01\n\x1eQueryCallTimelineEventsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x05since\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf6\x01\n\x1fQueryCallTimelineEventsResponse\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04next\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12U\n\x12participant_events\x18\x04 \x03(\x0b\x32\x39.stream.video.coordinator.stat_v1.CallParticipantTimeline2\x8a\x19\n\tServerRPC\x12w\n\x06GetApp\x12\x35.stream.video.coordinator.server_v1_rpc.GetAppRequest\x1a\x36.stream.video.coordinator.server_v1_rpc.GetAppResponse\x12\x80\x01\n\tUpdateApp\x12\x38.stream.video.coordinator.server_v1_rpc.UpdateAppRequest\x1a\x39.stream.video.coordinator.server_v1_rpc.UpdateAppResponse\x12\x8f\x01\n\x0e\x43reateCallType\x12=.stream.video.coordinator.server_v1_rpc.CreateCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.CreateCallTypeResponse\x12\x86\x01\n\x0bGetCallType\x12:.stream.video.coordinator.server_v1_rpc.GetCallTypeRequest\x1a;.stream.video.coordinator.server_v1_rpc.GetCallTypeResponse\x12\x8f\x01\n\x0eQueryCallTypes\x12=.stream.video.coordinator.server_v1_rpc.QueryCallTypesRequest\x1a>.stream.video.coordinator.server_v1_rpc.QueryCallTypesResponse\x12\x8f\x01\n\x0eUpdateCallType\x12=.stream.video.coordinator.server_v1_rpc.UpdateCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.UpdateCallTypeResponse\x12\x8f\x01\n\x0e\x44\x65leteCallType\x12=.stream.video.coordinator.server_v1_rpc.DeleteCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.DeleteCallTypeResponse\x12\x9b\x01\n\x12\x43reatePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.CreatePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.CreatePushProviderResponse\x12\x92\x01\n\x0fGetPushProvider\x12>.stream.video.coordinator.server_v1_rpc.GetPushProviderRequest\x1a?.stream.video.coordinator.server_v1_rpc.GetPushProviderResponse\x12\x9b\x01\n\x12QueryPushProviders\x12\x41.stream.video.coordinator.server_v1_rpc.QueryPushProvidersRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.QueryPushProvidersResponse\x12\x9b\x01\n\x12UpdatePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.UpdatePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.UpdatePushProviderResponse\x12\x9b\x01\n\x12\x44\x65letePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.DeletePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.DeletePushProviderResponse\x12\x8f\x01\n\x0eStartBroadcast\x12=.stream.video.coordinator.server_v1_rpc.StartBroadcastRequest\x1a>.stream.video.coordinator.server_v1_rpc.StartBroadcastResponse\x12\x8c\x01\n\rStopBroadcast\x12<.stream.video.coordinator.server_v1_rpc.StopBroadcastRequest\x1a=.stream.video.coordinator.server_v1_rpc.StopBroadcastResponse\x12\x8f\x01\n\x0eStartRecording\x12=.stream.video.coordinator.server_v1_rpc.StartRecordingRequest\x1a>.stream.video.coordinator.server_v1_rpc.StartRecordingResponse\x12\x8c\x01\n\rStopRecording\x12<.stream.video.coordinator.server_v1_rpc.StopRecordingRequest\x1a=.stream.video.coordinator.server_v1_rpc.StopRecordingResponse\x12\x8c\x01\n\rGetRecordings\x12<.stream.video.coordinator.server_v1_rpc.GetRecordingsRequest\x1a=.stream.video.coordinator.server_v1_rpc.GetRecordingsResponse\x12\x92\x01\n\x0f\x44\x65leteRecording\x12>.stream.video.coordinator.server_v1_rpc.DeleteRecordingRequest\x1a?.stream.video.coordinator.server_v1_rpc.DeleteRecordingResponse\x12\xaa\x01\n\x17QueryCallTimelineEvents\x12\x46.stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsRequest\x1aG.stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsResponse\x12\x83\x01\n\nCreateUser\x12\x39.stream.video.coordinator.server_v1_rpc.CreateUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.CreateUserResponse\x12\x83\x01\n\nDeleteUser\x12\x39.stream.video.coordinator.server_v1_rpc.DeleteUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.DeleteUserResponse\x12\x83\x01\n\nExportUser\x12\x39.stream.video.coordinator.server_v1_rpc.ExportUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.ExportUserResponseB\x0fZ\rserver_v1_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.server_v1_rpc.server_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rserver_v1_rpc'
  _GETAPPREQUEST._serialized_start=522
  _GETAPPREQUEST._serialized_end=537
  _GETAPPRESPONSE._serialized_start=539
  _GETAPPRESPONSE._serialized_end=606
  _UPDATEAPPREQUEST._serialized_start=608
  _UPDATEAPPREQUEST._serialized_end=693
  _UPDATEAPPRESPONSE._serialized_start=695
  _UPDATEAPPRESPONSE._serialized_end=765
  _PUSHPROVIDERINPUT._serialized_start=768
  _PUSHPROVIDERINPUT._serialized_end=1096
  _CREATEPUSHPROVIDERREQUEST._serialized_start=1098
  _CREATEPUSHPROVIDERREQUEST._serialized_end=1199
  _CREATEPUSHPROVIDERRESPONSE._serialized_start=1201
  _CREATEPUSHPROVIDERRESPONSE._serialized_end=1295
  _GETPUSHPROVIDERREQUEST._serialized_start=1297
  _GETPUSHPROVIDERREQUEST._serialized_end=1333
  _GETPUSHPROVIDERRESPONSE._serialized_start=1335
  _GETPUSHPROVIDERRESPONSE._serialized_end=1426
  _QUERYPUSHPROVIDERSREQUEST._serialized_start=1428
  _QUERYPUSHPROVIDERSREQUEST._serialized_end=1455
  _QUERYPUSHPROVIDERSRESPONSE._serialized_start=1457
  _QUERYPUSHPROVIDERSRESPONSE._serialized_end=1552
  _UPDATEPUSHPROVIDERREQUEST._serialized_start=1554
  _UPDATEPUSHPROVIDERREQUEST._serialized_end=1655
  _UPDATEPUSHPROVIDERRESPONSE._serialized_start=1657
  _UPDATEPUSHPROVIDERRESPONSE._serialized_end=1751
  _DELETEPUSHPROVIDERREQUEST._serialized_start=1753
  _DELETEPUSHPROVIDERREQUEST._serialized_end=1792
  _DELETEPUSHPROVIDERRESPONSE._serialized_start=1794
  _DELETEPUSHPROVIDERRESPONSE._serialized_end=1822
  _DELETECALLTYPEREQUEST._serialized_start=1824
  _DELETECALLTYPEREQUEST._serialized_end=1861
  _DELETECALLTYPERESPONSE._serialized_start=1863
  _DELETECALLTYPERESPONSE._serialized_end=1887
  _CREATECALLTYPEREQUEST._serialized_start=1889
  _CREATECALLTYPEREQUEST._serialized_end=1990
  _CREATECALLTYPERESPONSE._serialized_start=1992
  _CREATECALLTYPERESPONSE._serialized_end=2079
  _GETCALLTYPEREQUEST._serialized_start=2081
  _GETCALLTYPEREQUEST._serialized_end=2115
  _GETCALLTYPERESPONSE._serialized_start=2117
  _GETCALLTYPERESPONSE._serialized_end=2201
  _QUERYCALLTYPESREQUEST._serialized_start=2203
  _QUERYCALLTYPESREQUEST._serialized_end=2226
  _QUERYCALLTYPESRESPONSE._serialized_start=2228
  _QUERYCALLTYPESRESPONSE._serialized_end=2316
  _UPDATECALLTYPEREQUEST._serialized_start=2318
  _UPDATECALLTYPEREQUEST._serialized_end=2419
  _UPDATECALLTYPERESPONSE._serialized_start=2421
  _UPDATECALLTYPERESPONSE._serialized_end=2508
  _CREATECALLREQUEST._serialized_start=2511
  _CREATECALLREQUEST._serialized_end=2810
  _CREATEUSERREQUEST._serialized_start=2812
  _CREATEUSERREQUEST._serialized_end=2926
  _CREATEORUPDATEUSERSREQUEST._serialized_start=2928
  _CREATEORUPDATEUSERSREQUEST._serialized_end=3051
  _CREATEORUPDATEUSERSRESPONSE._serialized_start=3053
  _CREATEORUPDATEUSERSRESPONSE._serialized_end=3137
  _DELETEUSERREQUEST._serialized_start=3139
  _DELETEUSERREQUEST._serialized_end=3226
  _EXPORTUSERREQUEST._serialized_start=3228
  _EXPORTUSERREQUEST._serialized_end=3259
  _EXPORTUSERRESPONSE._serialized_start=3261
  _EXPORTUSERRESPONSE._serialized_end=3362
  _DELETEUSERRESPONSE._serialized_start=3364
  _DELETEUSERRESPONSE._serialized_end=3396
  _CREATEUSERRESPONSE._serialized_start=3398
  _CREATEUSERRESPONSE._serialized_end=3472
  _USERCAPABILITY._serialized_start=3474
  _USERCAPABILITY._serialized_end=3527
  _STARTBROADCASTREQUEST._serialized_start=3530
  _STARTBROADCASTREQUEST._serialized_end=3678
  _STARTBROADCASTRESPONSE._serialized_start=3680
  _STARTBROADCASTRESPONSE._serialized_end=3773
  _STOPBROADCASTREQUEST._serialized_start=3775
  _STOPBROADCASTREQUEST._serialized_end=3797
  _STOPBROADCASTRESPONSE._serialized_start=3799
  _STOPBROADCASTRESPONSE._serialized_end=3822
  _STORELATENCYREQUEST._serialized_start=3824
  _STORELATENCYREQUEST._serialized_end=3845
  _STORELATENCYRESPONSE._serialized_start=3847
  _STORELATENCYRESPONSE._serialized_end=3869
  _STARTRECORDINGREQUEST._serialized_start=3871
  _STARTRECORDINGREQUEST._serialized_end=3930
  _STARTRECORDINGRESPONSE._serialized_start=3932
  _STARTRECORDINGRESPONSE._serialized_end=3956
  _STOPRECORDINGREQUEST._serialized_start=3958
  _STOPRECORDINGREQUEST._serialized_end=4016
  _STOPRECORDINGRESPONSE._serialized_start=4018
  _STOPRECORDINGRESPONSE._serialized_end=4062
  _GETRECORDINGSREQUEST._serialized_start=4064
  _GETRECORDINGSREQUEST._serialized_end=4086
  _GETRECORDINGSRESPONSE._serialized_start=4088
  _GETRECORDINGSRESPONSE._serialized_end=4181
  _DELETERECORDINGREQUEST._serialized_start=4183
  _DELETERECORDINGREQUEST._serialized_end=4207
  _DELETERECORDINGRESPONSE._serialized_start=4209
  _DELETERECORDINGRESPONSE._serialized_end=4234
  _QUERYCALLTIMELINEEVENTSREQUEST._serialized_start=4237
  _QUERYCALLTIMELINEEVENTSREQUEST._serialized_end=4383
  _QUERYCALLTIMELINEEVENTSRESPONSE._serialized_start=4386
  _QUERYCALLTIMELINEEVENTSRESPONSE._serialized_end=4632
  _SERVERRPC._serialized_start=4635
  _SERVERRPC._serialized_end=7845
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/remote_control_rpc/remote_control_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4video/sfu/remote_control_rpc/remote_control_v1.proto\x12\x1fstream.video.sfu.remote_control\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dvideo/sfu/models/models.proto\"\x85\x01\n\x0fKickUserRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61ll_ids\x18\x03 \x03(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12.\n\nnot_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x12\n\x10KickUserResponse\"\x8c\x01\n\x16InvalidateTokenRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61ll_ids\x18\x03 \x03(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12.\n\nnot_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x19\n\x17InvalidateTokenResponse\"e\n\x17MuteParticipantsRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12:\n\x0cparticipants\x18\x02 \x03(\x0b\x32$.stream.video.sfu.models.Participant\"\x9f\x01\n\x14MuteParticipantInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\nsession_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nmute_audio\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x17\n\nmute_video\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\r\n\x0b_session_idB\r\n\x0b_mute_audioB\r\n\x0b_mute_video\"\x1a\n\x18MuteParticipantsResponse\"@\n\x0eGetCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nwith_state\x18\x03 \x01(\x08\"q\n\x0fGetCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x31\n\x05state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.models.CallState\"p\n\x11\x43reateCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12 \n\x18\x63\x61scading_sfus_hostnames\x18\x03 \x03(\t\x12\x1d\n\x15gossip_rpc_auth_token\x18\x04 \x01(\t\"A\n\x12\x43reateCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\"=\n\x0e\x45ndCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\">\n\x0f\x45ndCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call2\xe0\x04\n\x10RemoteControlRPC\x12o\n\x08KickUser\x12\x30.stream.video.sfu.remote_control.KickUserRequest\x1a\x31.stream.video.sfu.remote_control.KickUserResponse\x12\x87\x01\n\x10MuteParticipants\x12\x38.stream.video.sfu.remote_control.MuteParticipantsRequest\x1a\x39.stream.video.sfu.remote_control.MuteParticipantsResponse\x12l\n\x07GetCall\x12/.stream.video.sfu.remote_control.GetCallRequest\x1a\x30.stream.video.sfu.remote_control.GetCallResponse\x12u\n\nCreateCall\x12\x32.stream.video.sfu.remote_control.CreateCallRequest\x1a\x33.stream.video.sfu.remote_control.CreateCallResponse\x12l\n\x07\x45ndCall\x12/.stream.video.sfu.remote_control.EndCallRequest\x1a\x30.stream.video.sfu.remote_control.EndCallResponseB\x14Z\x12remote_control_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.remote_control_rpc.remote_control_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022remote_control_rpc'
  _KICKUSERREQUEST._serialized_start=154
  _KICKUSERREQUEST._serialized_end=287
  _KICKUSERRESPONSE._serialized_start=289
  _KICKUSERRESPONSE._serialized_end=307
  _INVALIDATETOKENREQUEST._serialized_start=310
  _INVALIDATETOKENREQUEST._serialized_end=450
  _INVALIDATETOKENRESPONSE._serialized_start=452
  _INVALIDATETOKENRESPONSE._serialized_end=477
  _MUTEPARTICIPANTSREQUEST._serialized_start=479
  _MUTEPARTICIPANTSREQUEST._serialized_end=580
  _MUTEPARTICIPANTINPUT._serialized_start=583
  _MUTEPARTICIPANTINPUT._serialized_end=742
  _MUTEPARTICIPANTSRESPONSE._serialized_start=744
  _MUTEPARTICIPANTSRESPONSE._serialized_end=770
  _GETCALLREQUEST._serialized_start=772
  _GETCALLREQUEST._serialized_end=836
  _GETCALLRESPONSE._serialized_start=838
  _GETCALLRESPONSE._serialized_end=951
  _CREATECALLREQUEST._serialized_start=953
  _CREATECALLREQUEST._serialized_end=1065
  _CREATECALLRESPONSE._serialized_start=1067
  _CREATECALLRESPONSE._serialized_end=1132
  _ENDCALLREQUEST._serialized_start=1134
  _ENDCALLREQUEST._serialized_end=1195
  _ENDCALLRESPONSE._serialized_start=1197
  _ENDCALLRESPONSE._serialized_end=1259
  _REMOTECONTROLRPC._serialized_start=1262
  _REMOTECONTROLRPC._serialized_end=1870
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Member(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """The CID of the Call this member belongs to"""
    user_id: builtins.str
    """The user ID of the member"""
    role: builtins.str
    """The role of the member in this room"""
    custom_json: builtins.bytes
    """Custom data for the member"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Created at timestamp"""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Updated at timestamp"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        user_id: builtins.str = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "created_at", b"created_at", "custom_json", b"custom_json", "role", b"role", "updated_at", b"updated_at", "user_id", b"user_id"]) -> None: ...

global___Member = Member



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/sfu/remote_control_rpc/remote_control_v1.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class RemoteControlRPCServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC"
		self._endpoints = {
			"KickUser": Endpoint(
				service_name="RemoteControlRPC",
				name="KickUser",
				function=getattr(service, "KickUser"),
				input=_sym_db.GetSymbol("stream.video.sfu.remote_control.KickUserRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.remote_control.KickUserResponse"),
			),
			"MuteParticipants": Endpoint(
				service_name="RemoteControlRPC",
				name="MuteParticipants",
				function=getattr(service, "MuteParticipants"),
				input=_sym_db.GetSymbol("stream.video.sfu.remote_control.MuteParticipantsRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.remote_control.MuteParticipantsResponse"),
			),
			"GetCall": Endpoint(
				service_name="RemoteControlRPC",
				name="GetCall",
				function=getattr(service, "GetCall"),
				input=_sym_db.GetSymbol("stream.video.sfu.remote_control.GetCallRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.remote_control.GetCallResponse"),
			),
			"CreateCall": Endpoint(
				service_name="RemoteControlRPC",
				name="CreateCall",
				function=getattr(service, "CreateCall"),
				input=_sym_db.GetSymbol("stream.video.sfu.remote_control.CreateCallRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.remote_control.CreateCallResponse"),
			),
			"EndCall": Endpoint(
				service_name="RemoteControlRPC",
				name="EndCall",
				function=getattr(service, "EndCall"),
				input=_sym_db.GetSymbol("stream.video.sfu.remote_control.EndCallRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.remote_control.EndCallResponse"),
			),
		}

class RemoteControlRPCClient(TwirpClient):

	def KickUser(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC/KickUser",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.remote_control.KickUserResponse"),
			**kwargs,
		)

	def MuteParticipants(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC/MuteParticipants",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.remote_control.MuteParticipantsResponse"),
			**kwargs,
		)

	def GetCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC/GetCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.remote_control.GetCallResponse"),
			**kwargs,
		)

	def CreateCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC/CreateCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.remote_control.CreateCallResponse"),
			**kwargs,
		)

	def EndCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.remote_control.RemoteControlRPC/EndCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.remote_control.EndCallResponse"),
			**kwargs,
		)



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: permissions/permissions_v1_rpc/permissions.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class PermissionsRPCServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC"
		self._endpoints = {
			"CreateRole": Endpoint(
				service_name="PermissionsRPC",
				name="CreateRole",
				function=getattr(service, "CreateRole"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.CreateRoleRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.CreateRoleResponse"),
			),
			"DeleteRole": Endpoint(
				service_name="PermissionsRPC",
				name="DeleteRole",
				function=getattr(service, "DeleteRole"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.DeleteRoleRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.DeleteRoleResponse"),
			),
			"QueryRoles": Endpoint(
				service_name="PermissionsRPC",
				name="QueryRoles",
				function=getattr(service, "QueryRoles"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryRolesRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryRolesResponse"),
			),
			"QueryScopes": Endpoint(
				service_name="PermissionsRPC",
				name="QueryScopes",
				function=getattr(service, "QueryScopes"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryScopesRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryScopesResponse"),
			),
			"UpdateScope": Endpoint(
				service_name="PermissionsRPC",
				name="UpdateScope",
				function=getattr(service, "UpdateScope"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.UpdateScopeRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.UpdateScopeResponse"),
			),
			"ResetScope": Endpoint(
				service_name="PermissionsRPC",
				name="ResetScope",
				function=getattr(service, "ResetScope"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.ResetScopeRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.ResetScopeResponse"),
			),
			"QueryActions": Endpoint(
				service_name="PermissionsRPC",
				name="QueryActions",
				function=getattr(service, "QueryActions"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryActionsRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryActionsResponse"),
			),
			"QueryPermissions": Endpoint(
				service_name="PermissionsRPC",
				name="QueryPermissions",
				function=getattr(service, "QueryPermissions"),
				input=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryPermissionsRequest"),
				output=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryPermissionsResponse"),
			),
		}

class PermissionsRPCClient(TwirpClient):

	def CreateRole(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/CreateRole",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.CreateRoleResponse"),
			**kwargs,
		)

	def DeleteRole(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/DeleteRole",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.DeleteRoleResponse"),
			**kwargs,
		)

	def QueryRoles(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/QueryRoles",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryRolesResponse"),
			**kwargs,
		)

	def QueryScopes(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/QueryScopes",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryScopesResponse"),
			**kwargs,
		)

	def UpdateScope(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/UpdateScope",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.UpdateScopeResponse"),
			**kwargs,
		)

	def ResetScope(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/ResetScope",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.ResetScopeResponse"),
			**kwargs,
		)

	def QueryActions(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/QueryActions",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryActionsResponse"),
			**kwargs,
		)

	def QueryPermissions(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.permissions.permissions_v1_rpc.PermissionsRPC/QueryPermissions",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.permissions.permissions_v1_rpc.QueryPermissionsResponse"),
			**kwargs,
		)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/user_v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/user_v1/user.proto\x12 stream.video.coordinator.user_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xce\x01\n\x04User\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\r\n\x05teams\x18\x02 \x03(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"^\n\tUserInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\r\n\x05teams\x18\x03 \x03(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x05 \x01(\x0c\x42\x31\x42\x06UserV1P\x01Z\x07user_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.user_v1.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006UserV1P\001Z\007user_v1\252\002\033Stream.Video.v1.Coordinator'
  _USER.fields_by_name['id']._options = None
  _USER.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _USER._serialized_start=133
  _USER._serialized_end=339
  _USERINPUT._serialized_start=341
  _USERINPUT._serialized_end=435
# @@protoc_insertion_point(module_scope)
